summaryrefslogtreecommitdiffstats
path: root/src/usr/util/utiltcemgr.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/util/utiltcemgr.H')
-rw-r--r--src/usr/util/utiltcemgr.H7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/usr/util/utiltcemgr.H b/src/usr/util/utiltcemgr.H
index 490f10e2e..c03d1d82c 100644
--- a/src/usr/util/utiltcemgr.H
+++ b/src/usr/util/utiltcemgr.H
@@ -136,11 +136,13 @@ class UtilTceMgr
void printIvMap() const;
/** Max TCE Entries and Size for the TCE Table */
enum
{
MAX_NUM_TCE_TABLE_ENTRIES = 0x080000, // 512k entries - HW Max
MAX_TCE_TABLE_SIZE = 0x400000, // 512k * 8 bytes/entry
+ MAX_TCE_MEMORY_SPACE = MAX_NUM_TCE_TABLE_ENTRIES * PAGESIZE,
};
/** Values related to PSIHB_SW_INTERFACES_t registers */
@@ -265,8 +267,7 @@ class UtilTceMgr
* - see utiltce.H for details
*
*/
- errlHndl_t deallocateTces(uint32_t i_startingToken,
- size_t i_size);
+ errlHndl_t deallocateTces(uint32_t i_startingToken);
/**
* @brief Responsible for disabling TCEs on the system, including
OpenPOWER on IntegriCloud
@@ -136,11 +136,13 @@ class UtilTceMgr
void printIvMap() const;
- /** Max TCE Entries and Size for the TCE Table */
+ /** Max TCE Entries and Size for the TCE Table. */
+ /** And Max amount of Memory The TCEs can cover. */
enum
{